__m256bh

Struct __m256bh 

1.89.0 · Source
pub struct __m256bh(/* private fields */);
Available on x86 and (x86 or x86-64) only.
256-bit wide set of 16 u16 types, x86-specific

This type is the same as the __m256bh type defined by Intel, representing a 256-bit SIMD register which internally is consisted of 16 packed u16 instances. Its purpose is for bf16 related intrinsic implementations.

The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.